@@ -1,31 +1,68 @@
+from enum import auto, Enum
 from PyQt5.QtCore import QEasingCurve, QPoint, QPropertyAnimation, Qt
 from PyQt5.QtGui import QPixmap
 from PyQt5.QtSvg import QSvgWidget
-from PyQt5.QtWidgets import QGraphicsOpacityEffect, QLabel, QVBoxLayout, QWidget
+from PyQt5.QtWidgets import QApplication, QLabel, QVBoxLayout, QWidget
 
 
-class Feedback(QWidget):
+class AnimationType(Enum):
+    """
+    Enumeration class for the type of animation. 
+    """
+    VERTICAL = 0
+    HORIZONTAL = 1
+    MAIN_DIAGONAL = 2
+    ANTI_DIAGONAL = 3
+
+
+class _Feedback(QWidget):
     """
     Abstract class for giving feedback in the form of toast notifications.
     """
-    def __init__(self) -> None:
+    def __init__(self, width: int = 100, height: int = 100) -> None:
         """
-        Initialisation method for Feedback class.
+        Initialisation method for Feedback class.\n
+        Args:
+            width (int): width of the notification
+            height (int): height of the notification
         """
-        super(Feedback, self).__init__()
+        super(_Feedback, self).__init__()
         self.setWindowFlags(Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint | Qt.X11BypassWindowManagerHint)
         self.setAttribute(Qt.WA_TranslucentBackground)
         self.layout = QVBoxLayout(self)
+        self.notification_width = width
+        self.notification_height = height
             
-    def show(self, start: QPoint, end: QPoint, time: int = 3000) -> None:
+    def show(self, type_of_animation: int, time: int = 3000) -> None:
         """
         Method for displaying a toast notification.\n
         Args:
-            start (QPoint): starting point
-            end (QPoint): ending point
+            type_of_animation (int): one of the preset types of animations in AnimationType enum class
             time (int): desired time of the flow in milliseconds
         """
-        super(Feedback, self).show()
+        # Obtaining the screen size.
+        screen = QApplication.primaryScreen().size()
+        width = screen.width()
+        height = screen.height()
+
+        # Vertical animation.
+        if type_of_animation == AnimationType.VERTICAL:
+            start = QPoint(width // 2 - self.notification_width // 2, height)
+            end = QPoint(width // 2 - self.notification_width // 2, 0)
+        # Horizontal animation.
+        elif type_of_animation == AnimationType.HORIZONTAL:
+            start = QPoint(0, height // 2 - self.notification_height // 2)
+            end = QPoint(width, height // 2 - self.notification_height // 2)
+        # Main diagonal animation.
+        elif type_of_animation == AnimationType.MAIN_DIAGONAL:
+            start = QPoint(width - self.notification_width, height - self.notification_height)
+            end = QPoint(0, 0)
+        # Antidiagonal animation.
+        elif type_of_animation == AnimationType.ANTI_DIAGONAL:
+            start = QPoint(0, height - self.notification_height)
+            end = QPoint(width - self.notification_width, 0)
+
+        super(_Feedback, self).show()
         self.flow(start, end, time)
 
     def flow(self, start: QPoint, end: QPoint, time: int) -> None:
@@ -54,15 +91,16 @@ class Feedback(QWidget):
         self.start_flow.start()
         self.start_opacity.start()
 
-class ImageFeedback(Feedback):
+
+class ImageFeedback(_Feedback):
     """
-    Class for giving image feedback in the form of toast notifications.
+    Class for giving image feedback in the form of toast notifications.\n
     Args:
         img (str): path to the image
         width (int): width of the image
         height (int): height of the image
     """
-    def __init__(self, img: str, width: int = 100, height: int = 100) -> None:
+    def __init__(self, img: str, width: int, height: int) -> None:
         """
         Initialisation method for ImageFeedback class.\n
         Args:
@@ -70,7 +108,7 @@ class ImageFeedback(Feedback):
             width (int): width of the image
             height (int): height of the image
         """
-        super(ImageFeedback, self).__init__()
+        super(ImageFeedback, self).__init__(width, height)
         self.img = img
 
         format = self.img.rsplit('.')[-1]  # Obtaining the format of the image.
@@ -88,22 +126,27 @@ class ImageFeedback(Feedback):
             self.label.setPixmap(pixmap)
 
 
-class TextFeedback(Feedback):
+class TextFeedback(_Feedback):
     """
-    Class for giving text feedback in the form of toast notifications.
+    Class for giving text feedback in the form of toast notifications.\n
     Args:
         text (str): text to be displayed
     """
     def __init__(self, text: str) -> None:
         """
-        Initialisation method for ImageFeedback class.
+        Initialisation method for ImageFeedback class.\n
         Args:
             img (str): path to the image
         """
         super(TextFeedback, self).__init__()
         self.text = text
-        
         self.label = QLabel(self)
         self.layout.addWidget(self.label)
-        self.label.setStyleSheet("background-color: white; border: 1px solid black;")
-        self.label.setText(self.text)
\ No newline at end of file
+        self.label.setStyleSheet('background-color: white;\
+                                  border: 1px solid black;\
+                                  font-size: 18pt;\
+                                  padding: 10px;')
+        self.label.setText(self.text)
+        self.label.adjustSize()
+        self.notification_width = self.label.width()
+        self.notification_height = self.label.height()
\ No newline at end of file
